import json

import numpy as np
import lightgbm as lgb
from sklearn.model_selection import train_test_split
from sklearn.datasets import make_classification
from sklearn.metrics import accuracy_score

with open("whole_data/x_data.json") as f1:
    x_list = json.loads(f1.read())
    X_train = np.array(x_list[:10000])
    X_test = np.array(x_list[10000:])

with open("whole_data/y_data.json") as f2:
    y_list = json.loads(f2.read())
    y_train = np.array(y_list[:10000])
    y_test = np.array(y_list[10000:])

# 创建LightGBM数据集
train_data = lgb.Dataset(X_train, label=y_train)
test_data = lgb.Dataset(X_test, label=y_test, reference=train_data)

# 设置模型的参数
params = {
    'objective': 'binary',  # 指定二分类任务
    'metric': 'binary_logloss',  # 评估指标为二分类的log损失
    'num_leaves': 31,  # 叶子节点数
    'learning_rate': 0.05,  # 学习率
    'bagging_fraction': 0.9,  # 建树的样本采样比例
    'feature_fraction': 0.8,  # 建树的特征选择比例
    'bagging_freq': 5,  # k 意味着每 k 次迭代执行bagging
}

# 训练模型
num_round = 100
bst = lgb.train(params, train_data, num_round, valid_sets=[test_data])

# 预测
y_pred = bst.predict(X_test, num_iteration=bst.best_iteration)
# 转换为二进制输出
y_pred_binary = np.where(y_pred > 0.5, 1, 0)

# 评估模型
accuracy = accuracy_score(y_test, y_pred_binary)
print(f'Accuracy: {accuracy}')
